Index: external/fastjet/plugins/SISCone/SISConePlugin.cc
===================================================================
--- external/fastjet/plugins/SISCone/SISConePlugin.cc	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/SISConePlugin.cc	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -78,7 +78,7 @@
 // static members declaration              //
 /////////////////////////////////////////////
-std::auto_ptr<SISConePlugin>           SISConePlugin::stored_plugin;
-std::auto_ptr<std::vector<PseudoJet> > SISConePlugin::stored_particles;
-std::auto_ptr<Csiscone>                SISConePlugin::stored_siscone;
+SharedPtr<SISConePlugin>           SISConePlugin::stored_plugin;
+SharedPtr<std::vector<PseudoJet> > SISConePlugin::stored_particles;
+SharedPtr<Csiscone>                SISConePlugin::stored_siscone;
 
 
Index: external/fastjet/plugins/SISCone/config.h
===================================================================
--- external/fastjet/plugins/SISCone/config.h	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/config.h	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -1,63 +1,117 @@
-/* siscone/config.h.  Generated from config.h.in by configure.  */
+#ifndef _SISCONE_CONFIG_H
+#define _SISCONE_CONFIG_H 1
+ 
+/* siscone/config.h. Generated automatically at end of configure. */
+/* siscone/config_raw.h.  Generated from config.h.in by configure.  */
 /* config.h.in.  Generated from configure.ac by autoheader.  */
 
 /* Define to 1 if you have the <dlfcn.h> header file. */
-#define HAVE_DLFCN_H 1
+#ifndef SISCONE_HAVE_DLFCN_H 
+#define SISCONE_HAVE_DLFCN_H  1 
+#endif
 
 /* Define to 1 if you have the <inttypes.h> header file. */
-#define HAVE_INTTYPES_H 1
+#ifndef SISCONE_HAVE_INTTYPES_H 
+#define SISCONE_HAVE_INTTYPES_H  1 
+#endif
 
 /* Define to 1 if you have the `m' library (-lm). */
-#define HAVE_LIBM 1
+#ifndef SISCONE_HAVE_LIBM 
+#define SISCONE_HAVE_LIBM  1 
+#endif
 
 /* Define to 1 if you have the <memory.h> header file. */
-#define HAVE_MEMORY_H 1
+#ifndef SISCONE_HAVE_MEMORY_H 
+#define SISCONE_HAVE_MEMORY_H  1 
+#endif
 
 /* Define to 1 if you have the <stdint.h> header file. */
-#define HAVE_STDINT_H 1
+#ifndef SISCONE_HAVE_STDINT_H 
+#define SISCONE_HAVE_STDINT_H  1 
+#endif
 
 /* Define to 1 if you have the <stdlib.h> header file. */
-#define HAVE_STDLIB_H 1
+#ifndef SISCONE_HAVE_STDLIB_H 
+#define SISCONE_HAVE_STDLIB_H  1 
+#endif
 
 /* Define to 1 if you have the <strings.h> header file. */
-#define HAVE_STRINGS_H 1
+#ifndef SISCONE_HAVE_STRINGS_H 
+#define SISCONE_HAVE_STRINGS_H  1 
+#endif
 
 /* Define to 1 if you have the <string.h> header file. */
-#define HAVE_STRING_H 1
+#ifndef SISCONE_HAVE_STRING_H 
+#define SISCONE_HAVE_STRING_H  1 
+#endif
 
 /* Define to 1 if you have the <sys/stat.h> header file. */
-#define HAVE_SYS_STAT_H 1
+#ifndef SISCONE_HAVE_SYS_STAT_H 
+#define SISCONE_HAVE_SYS_STAT_H  1 
+#endif
 
 /* Define to 1 if you have the <sys/types.h> header file. */
-#define HAVE_SYS_TYPES_H 1
+#ifndef SISCONE_HAVE_SYS_TYPES_H 
+#define SISCONE_HAVE_SYS_TYPES_H  1 
+#endif
 
 /* Define to 1 if you have the <unistd.h> header file. */
-#define HAVE_UNISTD_H 1
+#ifndef SISCONE_HAVE_UNISTD_H 
+#define SISCONE_HAVE_UNISTD_H  1 
+#endif
 
-/* Define to the sub-directory in which libtool stores uninstalled libraries.
-   */
-#define LT_OBJDIR ".libs/"
+/* Define to the sub-directory where libtool stores uninstalled libraries. */
+#ifndef SISCONE_LT_OBJDIR 
+#define SISCONE_LT_OBJDIR  ".libs/" 
+#endif
 
 /* Name of package */
-#define PACKAGE "siscone"
+#ifndef SISCONE_PACKAGE 
+#define SISCONE_PACKAGE  "siscone" 
+#endif
 
 /* Define to the address where bug reports for this package should be sent. */
-#define PACKAGE_BUGREPORT ""
+#ifndef SISCONE_PACKAGE_BUGREPORT 
+#define SISCONE_PACKAGE_BUGREPORT  "" 
+#endif
 
 /* Define to the full name of this package. */
-#define PACKAGE_NAME "SISCone"
+#ifndef SISCONE_PACKAGE_NAME 
+#define SISCONE_PACKAGE_NAME  "SISCone" 
+#endif
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "SISCone 3.0.0"
+#ifndef SISCONE_PACKAGE_STRING 
+#define SISCONE_PACKAGE_STRING  "SISCone 3.0.3" 
+#endif
 
 /* Define to the one symbol short name of this package. */
-#define PACKAGE_TARNAME "siscone"
+#ifndef SISCONE_PACKAGE_TARNAME 
+#define SISCONE_PACKAGE_TARNAME  "siscone" 
+#endif
+
+/* Define to the home page for this package. */
+#ifndef SISCONE_PACKAGE_URL 
+#define SISCONE_PACKAGE_URL  "" 
+#endif
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "3.0.0"
+#ifndef SISCONE_PACKAGE_VERSION 
+#define SISCONE_PACKAGE_VERSION  "3.0.3" 
+#endif
 
 /* Define to 1 if you have the ANSI C header files. */
-#define STDC_HEADERS 1
+#ifndef SISCONE_STDC_HEADERS 
+#define SISCONE_STDC_HEADERS  1 
+#endif
+
+/* use unique_ptr instead of auto_ptr */
+/* #undef USES_UNIQUE_PTR_AS_AUTO_PTR */
 
 /* Version number of package */
-#define VERSION "3.0.0"
+#ifndef SISCONE_VERSION 
+#define SISCONE_VERSION  "3.0.3" 
+#endif
+ 
+/* once: _SISCONE_CONFIG_H */
+#endif
Index: external/fastjet/plugins/SISCone/config_raw.h
===================================================================
--- external/fastjet/plugins/SISCone/config_raw.h	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
+++ external/fastjet/plugins/SISCone/config_raw.h	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -0,0 +1,68 @@
+/* siscone/config_raw.h.  Generated from config.h.in by configure.  */
+/* config.h.in.  Generated from configure.ac by autoheader.  */
+
+/* Define to 1 if you have the <dlfcn.h> header file. */
+#define HAVE_DLFCN_H 1
+
+/* Define to 1 if you have the <inttypes.h> header file. */
+#define HAVE_INTTYPES_H 1
+
+/* Define to 1 if you have the `m' library (-lm). */
+#define HAVE_LIBM 1
+
+/* Define to 1 if you have the <memory.h> header file. */
+#define HAVE_MEMORY_H 1
+
+/* Define to 1 if you have the <stdint.h> header file. */
+#define HAVE_STDINT_H 1
+
+/* Define to 1 if you have the <stdlib.h> header file. */
+#define HAVE_STDLIB_H 1
+
+/* Define to 1 if you have the <strings.h> header file. */
+#define HAVE_STRINGS_H 1
+
+/* Define to 1 if you have the <string.h> header file. */
+#define HAVE_STRING_H 1
+
+/* Define to 1 if you have the <sys/stat.h> header file. */
+#define HAVE_SYS_STAT_H 1
+
+/* Define to 1 if you have the <sys/types.h> header file. */
+#define HAVE_SYS_TYPES_H 1
+
+/* Define to 1 if you have the <unistd.h> header file. */
+#define HAVE_UNISTD_H 1
+
+/* Define to the sub-directory where libtool stores uninstalled libraries. */
+#define LT_OBJDIR ".libs/"
+
+/* Name of package */
+#define PACKAGE "siscone"
+
+/* Define to the address where bug reports for this package should be sent. */
+#define PACKAGE_BUGREPORT ""
+
+/* Define to the full name of this package. */
+#define PACKAGE_NAME "SISCone"
+
+/* Define to the full name and version of this package. */
+#define PACKAGE_STRING "SISCone 3.0.3"
+
+/* Define to the one symbol short name of this package. */
+#define PACKAGE_TARNAME "siscone"
+
+/* Define to the home page for this package. */
+#define PACKAGE_URL ""
+
+/* Define to the version of this package. */
+#define PACKAGE_VERSION "3.0.3"
+
+/* Define to 1 if you have the ANSI C header files. */
+#define STDC_HEADERS 1
+
+/* use unique_ptr instead of auto_ptr */
+/* #undef USES_UNIQUE_PTR_AS_AUTO_PTR */
+
+/* Version number of package */
+#define VERSION "3.0.3"
Index: external/fastjet/plugins/SISCone/defines.h
===================================================================
--- external/fastjet/plugins/SISCone/defines.h	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/defines.h	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -22,6 +22,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA //
 //                                                                           //
-// $Revision:: 225                                                          $//
-// $Date:: 2008-05-20 16:59:47 +0200 (Tue, 20 May 2008)                     $//
+// $Revision:: 401                                                          $//
+// $Date:: 2016-05-19 16:44:37 +0200 (Thu, 19 May 2016)                     $//
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -35,7 +35,7 @@
 // defined in siscone.h
 // Otherwise, config.h
-// It is also defined as "PACKAGE_NAME" in config.h but this method 
+// It is also defined as "SISCONE_PACKAGE_NAME" in config.h but this method 
 // might lead to conflicts
-//#define PROGRAM   PACKAGE_NAME 
+//#define PROGRAM   SISCONE_PACKAGE_NAME 
 
 // program version
@@ -43,5 +43,5 @@
 //   siscone::siscone_version
 // defined in siscone.h
-// It is also defined as "VERSION" in config.h but this method 
+// It is also defined as "SISCONE_VERSION" in config.h but this method 
 // might lead to conflicts
 
Index: external/fastjet/plugins/SISCone/fastjet/SISConePlugin.hh
===================================================================
--- external/fastjet/plugins/SISCone/fastjet/SISConePlugin.hh	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/fastjet/SISConePlugin.hh	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -191,7 +191,7 @@
   // part needed for the cache 
   // variables for caching the results and the input
-  static std::auto_ptr<SISConePlugin          > stored_plugin;
-  static std::auto_ptr<std::vector<PseudoJet> > stored_particles;
-  static std::auto_ptr<siscone::Csiscone      > stored_siscone;
+  static SharedPtr<SISConePlugin          > stored_plugin;
+  static SharedPtr<std::vector<PseudoJet> > stored_particles;
+  static SharedPtr<siscone::Csiscone      > stored_siscone;
 };
 
Index: external/fastjet/plugins/SISCone/fastjet/SISConeSphericalPlugin.hh
===================================================================
--- external/fastjet/plugins/SISCone/fastjet/SISConeSphericalPlugin.hh	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/fastjet/SISConeSphericalPlugin.hh	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -166,7 +166,7 @@
   // part needed for the cache 
   // variables for caching the results and the input
-  static std::auto_ptr<SISConeSphericalPlugin        > stored_plugin;
-  static std::auto_ptr<std::vector<PseudoJet>        > stored_particles;
-  static std::auto_ptr<siscone_spherical::CSphsiscone> stored_siscone;
+  static SharedPtr<SISConeSphericalPlugin        > stored_plugin;
+  static SharedPtr<std::vector<PseudoJet>        > stored_particles;
+  static SharedPtr<siscone_spherical::CSphsiscone> stored_siscone;
 };
 
Index: external/fastjet/plugins/SISCone/siscone.h
===================================================================
--- external/fastjet/plugins/SISCone/siscone.h	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/siscone.h	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -22,6 +22,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA //
 //                                                                           //
-// $Revision:: 369                                                          $//
-// $Date:: 2014-09-04 16:57:55 +0200 (Thu, 04 Sep 2014)                     $//
+// $Revision:: 401                                                          $//
+// $Date:: 2016-05-19 16:44:37 +0200 (Thu, 19 May 2016)                     $//
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -160,6 +160,6 @@
  * return SISCone package name.
  * This is nothing but "SISCone", it is a replacement to the
- * PACKAGE_NAME string defined in config.h and which is not
- * public by default.
+ * SISCONE_PACKAGE_NAME string defined in config.h and which is not
+ * guaranteed to be public.
  * \return the SISCone name as a string
  */
Index: external/fastjet/plugins/SISCone/split_merge.cc
===================================================================
--- external/fastjet/plugins/SISCone/split_merge.cc	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/split_merge.cc	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -21,6 +21,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA //
 //                                                                           //
-// $Revision:: 370                                                          $//
-// $Date:: 2014-09-04 17:03:15 +0200 (Thu, 04 Sep 2014)                     $//
+// $Revision:: 390                                                          $//
+// $Date:: 2016-03-03 11:06:52 +0100 (Thu, 03 Mar 2016)                     $//
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -54,4 +54,6 @@
   pt_tilde = 0.0;
   sm_var2 = 0.0;
+  pass = CJET_INEXISTENT_PASS; // initialised to a value that should
+                               // notappear in the end (after clustering)
 }
 
@@ -659,5 +661,5 @@
 
 #ifdef DEBUG_SPLIT_MERGE
-  cout << "PR-Jet " << jets.size() << " [size " << next_jet.contents.size() << "]:";
+  cout << "PR-Jet " << jets.size() << " [size " << jet.contents.size() << "]:";
 #endif
     
@@ -1179,6 +1181,6 @@
   }
 
-  return 0.0;
-}
-
-}
+  //return 0.0;
+}
+
+}
Index: external/fastjet/plugins/SISCone/split_merge.h
===================================================================
--- external/fastjet/plugins/SISCone/split_merge.h	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/split_merge.h	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -22,6 +22,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA //
 //                                                                           //
-// $Revision:: 367                                                          $//
-// $Date:: 2014-09-04 15:57:37 +0200 (Thu, 04 Sep 2014)                     $//
+// $Revision:: 405                                                          $//
+// $Date:: 2016-05-23 20:15:02 +0200 (Mon, 23 May 2016)                     $//
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -29,4 +29,5 @@
 #define __SPLIT_MERGE_H__
 
+#include "config.h"
 #include "defines.h"
 #include "geom_2d.h"
@@ -39,4 +40,6 @@
 
 namespace siscone{
+
+const int CJET_INEXISTENT_PASS = -2;
 
 /**
@@ -75,4 +78,6 @@
   /// pass at which the jet has been found
   /// It starts at 0 (first pass), -1 means infinite rapidity
+  /// (it will be initialised to "CJET_INEXISTENT_PASS" which should
+  /// never appear after clustering)
   int pass;
 };
@@ -441,6 +446,10 @@
   // jet information
   /// list of jet candidates
+#ifdef SISCONE_USES_UNIQUE_PTR_AS_AUTO_PTR
+  std::unique_ptr<std::multiset<Cjet,Csplit_merge_ptcomparison> > candidates;
+#else
   std::auto_ptr<std::multiset<Cjet,Csplit_merge_ptcomparison> > candidates;
-
+#endif
+  
   /// minimal pt2
   double pt_min2;
Index: external/fastjet/plugins/SISCone/vicinity.cc
===================================================================
--- external/fastjet/plugins/SISCone/vicinity.cc	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/vicinity.cc	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -21,6 +21,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA //
 //                                                                           //
-// $Revision:: 123                                                          $//
-// $Date:: 2007-03-01 02:52:16 +0100 (Thu, 01 Mar 2007)                     $//
+// $Revision:: 388                                                          $//
+// $Date:: 2016-03-03 10:42:25 +0100 (Thu, 03 Mar 2016)                     $//
 ///////////////////////////////////////////////////////////////////////////////
 
@@ -80,4 +80,5 @@
   VR2 = VR = 0.0;
 
+  ve_list = NULL;
   set_particle_list(_particle_list);
 }

Index: external/fastjet/plugins/SISCone/siscone.cc
===================================================================
--- external/fastjet/plugins/SISCone/siscone.cc	(revision 10e33bc4e6edb559fb6355f044aed3785d788662)
+++ external/fastjet/plugins/SISCone/siscone.cc	(revision 1d208a26c5a0e04af264db9dd7e0ec1daf2b8235)
@@ -21,16 +21,9 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA //
 //                                                                           //
-// $Revision:: 371                                                          $//
-// $Date:: 2014-09-09 10:05:32 +0200 (Tue, 09 Sep 2014)                     $//
+// $Revision:: 403                                                          $//
+// $Date:: 2016-05-19 16:52:05 +0200 (Thu, 19 May 2016)                     $//
 ///////////////////////////////////////////////////////////////////////////////
 
-//#ifdef HAVE_CONFIG_H
 #include "config.h"
-//#else
-//#define PACKAGE_NAME "SISCone"
-//#define VERSION "3.0.0"
-//#warning "No config.h file available, using preset values"
-//#endif
-
 #include "ranlux.h"
 #include "momentum.h"
@@ -254,4 +247,6 @@
   // print the banner
   if (_banner_ostr != 0){
+    ios::fmtflags flags_to_restore(_banner_ostr->flags());
+
     (*_banner_ostr) << "#ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo" << endl;
     (*_banner_ostr) << "#                    SISCone   version " << setw(28) << left << siscone_version() << "o" << endl;
@@ -269,4 +264,5 @@
 
     _banner_ostr->flush();
+    _banner_ostr->flags(flags_to_restore);
   }
 }
@@ -279,10 +275,10 @@
  * return SISCone package name.
  * This is nothing but "SISCone", it is a replacement to the
  * PACKAGE_NAME string defined in config.h and which is not
  * public by default.
  * return the SISCone name as a string
  */
 string siscone_package_name(){
-  return PACKAGE_NAME;
+  return SISCONE_PACKAGE_NAME;
 }
 
@@ -293,6 +289,6 @@
  */
 string siscone_version(){
-  return VERSION;
-}
-
-}
+  return SISCONE_VERSION;
+}
+
+}
@@ -279,10 +275,10 @@
  * return SISCone package name.
  * This is nothing but "SISCone", it is a replacement to the
- * PACKAGE_NAME string defined in config.h and which is not
- * public by default.
+ * SISCONE_PACKAGE_NAME string defined in config.h and which is not
+ * guaranteed to be public.
  * return the SISCone name as a string
  */